<?php
/**
 *
 * Register Menus, Sidebars, Footer widgets
 *
 * @package Chirsty
 * @since Chirsty 1.0
 */

/**
    Menus & Navigation
**/

// Primary menu
function chirsty_main_nav() {
  wp_nav_menu(array(
    'menu'              => esc_html__('Primary', 'chirsty'),
    'theme_location'    => 'primary',
    'container'         => false,
    'menu_class'        => 'nav navbar-nav',
    'fallback_cb'       => 'Chirsty_Bootstrap_Navwalker::fallback',
    'walker'            => new Chirsty_Bootstrap_Navwalker()
    ) 
  );
}
function chirsty_main_nav_mobile() {
  wp_nav_menu(array(
    'menu'              => esc_html__('Mobile', 'chirsty'),
    'theme_location'    => 'mobilem',
    'container'         => false,
    'menu_class'        => 'nav navbar-nav',
    'fallback_cb'       => 'Chirsty_Bootstrap_Navwalker::fallback',
    'walker'            => new Chirsty_Bootstrap_Navwalker()
    ) 
  );
}

// Footer menu
function chirsty_footer_nav() {
  wp_nav_menu(array(
    'menu'              => esc_html__('Footer Menu', 'chirsty'),
    'theme_location'    => 'footer-menu',
    'container'         => false,
    'menu_class'        => 'unstyled',
    'fallback_cb'       => 'Chirsty_Bootstrap_Navwalker_Footer::fallback',
    'walker'            => new Chirsty_Bootstrap_Navwalker_Footer()
    ) 
  );
}

function chirsty_add_sidebar_offc($items, $args) {
    if($args->theme_location == 'primary' && chirsty_get_option('navbar_search') ) {
        $sidebaroffc = '
        <li id="sidebar-offcanvas">
			 <a class="navbar-toggle" onclick="openNav2()">
				<i class="fa fa-bars" aria-hidden="true"></i>
			</a>
        </li>';
        $items .= $sidebaroffc;
    }
    return $items;
}
add_filter('wp_nav_menu_items', 'chirsty_add_sidebar_offc', 10, 2);

/**
    Add search box to Navigation menu
**/
function chirsty_add_search_box($items, $args) {
    if($args->theme_location == 'primary' && chirsty_get_option('navbar_search') ) {
        $searchlink = '
        <li id="search_dropdown">
			<a href="#searchmenu" class=" "> <i class="fa fa-search"></i> </a>
               
            <ul id="searchmenu" class="top-search-row">
				<li class="top-search-cell">
					<span class="close"> </span>

					<form class="searchmenu-navbar-form" role="search" action="'. esc_url( get_home_url( '/' ) ) . '">     
						<div class="input-group tpsrc">
							 
							<input type="text" name="s" class="searchmenu-popup" value="" placeholder="' . sprintf (esc_attr__('Search', 'chirsty') ) . '"/> 					
						</div>
							<button class="searchbtncc ribbon elementor-animation-push"><i class="fa fa-search"></i></button>
					</form>
				</li>
			</ul>
        </li>';
        $items .= $searchlink;
    }
    return $items;
}
add_filter('wp_nav_menu_items', 'chirsty_add_search_box', 10, 2);


/**
    Register widgetized area and update sidebar with default widgets
**/

function chirsty_widgets_init() {

  // add sidebars
  register_sidebar( array(
    'name'          => esc_html__( 'Posts Sidebar', 'chirsty' ),
    'id'            => 'sidebar',
    'description'   => esc_html__('The default sidebar, place widgets here will show in all posts', 'chirsty'),
    'before_widget' => '<div id="%1$s" class="widget %2$s">',
    'after_widget'  => '</div>',
    'before_title'  => '<h4 class="widget-title">',
    'after_title'   => '</h4>',
   ) );
  register_sidebar( array(
    'name'          => esc_html__( 'Pages Sidebar', 'chirsty' ),
    'id'            => 'sidebar-2',
    'description'   => esc_html__('The second sidebar, place widgets here will show in all pages','chirsty'),
    'before_widget' => '<div id="%1$s" class="widget %2$s">',
    'after_widget'  => '</div>',
    'before_title'  => '<h4 class="widget-title">',
    'after_title'   => '</h4>',
   ) ); 
  register_sidebar( array(
    'name'          => esc_html__( 'Blog page Sidebar', 'chirsty' ),
    'id'            => 'sidebar-3',
    'description'   => esc_html__('The second sidebar, place widgets here will show in all pages','chirsty'),
    'before_widget' => '<div id="%1$s" class="widget %2$s">',
    'after_widget'  => '</div>',
    'before_title'  => '<h4 class="widget-title">',
    'after_title'   => '</h4>',
   ) ); 
   
register_sidebar( array(
    'name'          => esc_html__( 'Shop', 'chirsty' ),
    'id'            => 'shop-woo',
    'description'   => esc_html__('Shop sidebar','chirsty'),
    'before_widget' => '<div id="%1$s" class="widget %2$s">',
    'after_widget'  => '</div>',
    'before_title'  => '<h4 class="widget-title">',
    'after_title'   => '</h4>',
   ) ); 
   register_sidebar( array(
    'name'          => esc_html__( 'Single Product', 'chirsty' ),
    'id'            => 'single-product-woo',
    'description'   => esc_html__('Single Product','chirsty'),
    'before_widget' => '<div id="%1$s" class="widget %2$s">',
    'after_widget'  => '</div>',
    'before_title'  => '<h4 class="widget-title">',
    'after_title'   => '</h4>',
   ) ); 
   
   
   
  // add footer widgets
  switch (chirsty_get_option('footer_col')) {
  
    case '1':
    register_sidebar(array(
     'name'          => esc_html__( 'Footer Widget 1', 'chirsty' ),
     'id'            => 'footer-widget-1',
     'description'   => esc_html__('The first Row of Footer Widgets, place widgets as per no. of footer widgets setting you set in Theme Options', 'chirsty'),
     'before_widget' => '<div class="footer-widgets col-md-12 %2$s" id="%1$s">',
     'after_widget'  => '</div>',
     'before_title'  => '<h4 class="footer-widget-title">',
     'after_title'   => '</h4>',
     ) );
    break;

    case '2':
    register_sidebar(array(
     'name'          => esc_html__( 'Footer Widget 1', 'chirsty' ),
     'id'            => 'footer-widget-1',
     'description'   => esc_html__('The first Row of Footer Widgets, place widgets as per no. of footer widgets setting you set in Theme Options', 'chirsty'),
     'before_widget' => '<div class="footer-widgets col-md-6 %2$s" id="%1$s">',
     'after_widget'  => '</div>',
     'before_title'  => '<h4 class="footer-widget-title">',
     'after_title'   => '</h4>',
     ) );
    break;

    case '3':
    register_sidebar(array(
     'name'          => esc_html__( 'Footer Widget 1', 'chirsty' ),
     'id'            => 'footer-widget-1',
     'description'   => esc_html__('The first Row of Footer Widgets, place widgets as per no. of footer widgets setting you set in Theme Options', 'chirsty'),
     'before_widget' => '<div class="footer-widgets col-md-4 %2$s" id="%1$s">',
     'after_widget'  => '</div>',
     'before_title'  => '<h4 class="footer-widget-title">',
     'after_title'   => '</h4>',
     ) );
    break;

    case '4':
    register_sidebar(array(
     'name'          => esc_html__( 'Footer Widget 1', 'chirsty' ),
     'id'            => 'footer-widget-1',
     'description'   => esc_html__('The first Row of Footer Widgets, place widgets as per no. of footer widgets setting you set in Theme Options', 'chirsty'),
     'before_widget' => '<div class="footer-widgets col-md-3 %2$s" id="%1$s">',
     'after_widget'  => '</div>',
     'before_title'  => '<h4 class="footer-widget-title">',
     'after_title'   => '</h4>',
     ) );
    break;
  }

}

add_action( 'widgets_init', 'chirsty_widgets_init' );

/*Comments*/

if ( ! function_exists( 'chirsty_comment' ) ) {
	function chirsty_comment( $comment, $args, $depth )
	{
		$GLOBALS['comment'] = $comment;

		switch ( $comment->comment_type ):
			case 'pingback':
			case 'trackback': ?>
				<div class="pingback">
					<div class="inside-pb">
						<span><?php esc_html_e( 'Pingback:', 'chirsty' ); ?> </span> 
						<div><?php comment_author_link(); ?></div>
						<?php edit_comment_link( esc_html__( '(Edit)', 'chirsty' ), '<span class="edit-link">', '</span>' ); ?>
					</div>
				</div>
				<?php
				break;
			default: ?>
				<li <?php comment_class('chirsty-sec'); ?> id="li-comment-<?php comment_ID(); ?>">
					<div class="comment" id="comment-<?php comment_ID(); ?>">
						<div class="comment-author vcard">
							<?php echo get_avatar( $comment, 110, '', '', array( 'class' => 'img-responsive' ) ); ?>
						</div>
						<div class="comment-body">
							<div class="title-ccc"><?php comment_author(); ?></div>
							<div class="comment-meta">
								<span class="comm-dat"><?php comment_date( get_option('date_format') );?></span>
							</div>
							<div class="footer-desc">
								<?php comment_text(); ?>
							
							
								
								<?php comment_reply_link(
									array_merge( $args,
										array(
											'reply_text' => esc_html__( 'Reply', 'chirsty' ),
											'after' 	 => '',
											'depth' 	 => $depth,
											'max_depth'  => $args['max_depth']
										)
									)
								); ?>
								
							</div>
						</div>
						
					</div>
					</li>
			<?php
			break;
		endswitch;
	}
}


/*Gutenberg*/


function chirsty_gutenberg_editor_palette_styles() {
    add_theme_support( 'editor-color-palette', array(
        array(
            'name' => esc_html__( 'strong red', 'chirsty' ),
            'slug' => 'strong-red',
            'color' => '#dd0808',
        ),
        array(
            'name' => esc_html__( 'strong white', 'chirsty' ),
            'slug' => 'strong-white',
            'color' => '#fff',
        ),
		array(
            'name' => esc_html__( 'light black', 'chirsty' ),
            'slug' => 'light-black',
            'color' => '#000000',
        ),
        array(
            'name' => esc_html__( 'very light gray', 'chirsty' ),
            'slug' => 'very-light-gray',
            'color' => '#797979',
        ),
        array(
            'name' => esc_html__( 'very dark black', 'chirsty' ),
            'slug' => 'very-dark-black',
            'color' => '#000000',
        ),
    ) );

		// Add custom editor font sizes.
		add_theme_support( 'editor-font-sizes', array(
				array(
					'name'      => esc_html__( 'Small', 'chirsty' ),
					'size'      => 14,
					'slug'      => 'small',
				),
				array(
					'name'      => esc_html__( 'Normal', 'chirsty' ),
					'size'      => 16,
					'slug'      => 'normal',
				),
				array(
					'name'      => esc_html__( 'Large', 'chirsty' ),
					'size'      => 40,
					'slug'      => 'large',
				),
				array(
					'name'      => esc_html__( 'Huge', 'chirsty' ),
					'size'      => 50,
					'slug'      => 'huge',
				),
			)
		);
}
add_action( 'after_setup_theme', 'chirsty_gutenberg_editor_palette_styles' );

function chirsty_theme_add_editor_styles() {
    add_editor_style( 'custom-editor-style.css' );
}
add_action( 'admin_init', 'chirsty_theme_add_editor_styles' );