<?php
    /**
     * ReduxFramework Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

	  if ( ! class_exists( 'Redux' ) ) {
        return;
    }
 
// This is your option name where all the Redux data is stored.
    $ochirsty_name = "chirsty_settings";
	
    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'ochirsty_name'             => $ochirsty_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => true,
        // Show the sections below the admin menu item or not
        'menu_title'           => esc_html__( 'Chirsty Options', 'chirsty' ),
        'page_title'           => esc_html__( 'Chirsty Options', 'chirsty' ),
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => true,
        // Use a asynchronous font on the front end or font string
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-admin-generic',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the ochirsty_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'update_notice'        => false,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => true,
        // OPTIONAL -> Give you extra features
        'page_priority'        => null,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => '',
        // Page slug used to denote the panel, will be based off page title then menu title then ochirsty_name if not provided
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
        'system_info'          => false,
        // REMOVE

        //'compiler'             => true,

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'light',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );

    // Panel Intro text -> before the form
    if ( ! isset( $args['global_variable'] ) || $args['global_variable'] !== false ) {
        if ( ! empty( $args['global_variable'] ) ) {
            $v = $args['global_variable'];
        } else {
            $v = str_replace( '-', '_', $args['ochirsty_name'] );
        }
            $args['intro_text'] = sprintf( esc_html__( 'Did you know that Redux sets a global variable for you? To access any of your saved options from within your code you can use your global variable: $%1$s', 'chirsty' ), $v );
        } 
        else {
            $args['intro_text'] = esc_html__( 'This text is displayed above the options panel. It isn\'t required, but more info is always better! The intro_text field accepts all HTML.', 'chirsty' );
        }

    // Add content after the form.
    $args['footer_text'] = esc_html__( 'This text is displayed below the options panel. It isn\'t required, but more info is always better! The footer_text field accepts all HTML.', 'chirsty' );

    Redux::setArgs( $ochirsty_name, $args );


Redux::setSection( $ochirsty_name, array(
    'icon' => 'el el-icon-cog',
    'title' => esc_html__('General', 'chirsty'),
    'fields' => array(
        array(
            'id' => 'info_success',
            'type' => 'info',
            'style' => 'success',
            'title' => esc_html__('Welcome to Chirsty Theme Option Panel', 'chirsty'),
            'icon' => 'el el-icon-smiley',
            'desc' => esc_html__('From here you can config your theme in the way you like.', 'chirsty')
        ),
        array(
            'id' => 'favicon',
            'type' => 'media',
            'url' => true,
            'title' => esc_html__('Favicon', 'chirsty'),
            'subtitle' => esc_html__('Upload your favicon here', 'chirsty'),
            'desc' => esc_html__('Should be 16 x 16px Supported formats: .ico .gif .png', 'chirsty'),
            'default' => ''
        ),

        array(
            'id' => 'apple_touch_icon',
            'type' => 'media',
            'url' => true,
            'title' => esc_html__('Apple Touch Icon', 'chirsty'),
            'subtitle' => esc_html__('Upload icon for the Apple touch', 'chirsty'),
            'desc' => esc_html__('Size: 57 x 57px Supported formats: .ico .gif .png', 'chirsty'),
            'default' => ''
        ),

        array(
            'id' => 'scroll_to_top',
            'type' => 'switch',
            'title' => esc_html__('Scroll to top button', 'chirsty'),
            'subtitle' => esc_html__('Check if you want to disable scroll to top button', 'chirsty'),
            'default' => false
        ),
		array(
            'id' => 'main_colorr',
            'type' => 'color',
            'title' => esc_html__('Main color', 'chirsty'),
            'subtitle' => esc_html__('main color', 'chirsty'),
            'transparent' => false,
            'default' => '#d40708'
        ),
    )
) );

/* Header */
Redux::setSection( $ochirsty_name,array(
    'icon' => 'el el-icon-user',
    'title' => esc_html__('Header', 'chirsty'),
    'desc' => esc_html__('These are options to modify and style your header area', 'chirsty'),
    'fields' => array(
        array(
            'id' => 'logo',
            'type' => 'media',
            'url' => true,
            'title' => esc_html__('Logo', 'chirsty'),
            'subtitle' => esc_html__('Upload your logo image here, or leave empty to show website title instead', 'chirsty'),
            'desc' => esc_html__('Note: Allowed extensions are .jpg, .png and .gif', 'chirsty'),
            'default' => get_template_directory_uri() . '/images/logo.png',


        ),
        array(
            'id' => 'logo_width',
            'type' => 'slider',
            'title' => esc_html__('Logo Width', 'chirsty'),
            'subtitle' => esc_html__('Specify your logo width.', 'chirsty'),
            'validate' => 'numeric',
            "min" => "50",
            "step" => "1",
            "max" => "300",
            'default' => "50"
        ),
        array(
            'id' => 'logo_height',
            'type' => 'slider',
            'title' => esc_html__('Logo Height', 'chirsty'),
            'subtitle' => esc_html__('Specify your logo height.', 'chirsty'),
            'validate' => 'numeric',
            "min" => "10",
            "step" => "1",
            "max" => "300",
            'default' => "53"
        ),
        array(
            'id' => 'header_description',
            'type' => 'switch',
            'title' => esc_html__('Display site description', 'chirsty'),
            'subtitle' => esc_html__('Check if you want to display site description.', 'chirsty'),
            'desc' => esc_html__('Note: It will apply only if You remove logo image. You can change your site description inside -Settings - General', 'chirsty'),
            'default' => false,
        ),

        array(
            'id' => 'header_layout',
            'type' => 'image_select',
            'title' => esc_html__('Header Type', 'chirsty'),
            'subtitle' => esc_html__('Select your header layout: In next updates, we here will be different header types, now both are the same.', 'chirsty'),
            'options' => array(
                'default' => array(
                    'title' => esc_html__('Style One', 'chirsty'),
                    'img' => CHIRSTY_IMG_URI . '/1column.png',
                ),
                'transparent' => array(
                    'title' => esc_html__('Transparent', 'chirsty'),
                    'img' => CHIRSTY_IMG_URI . '/2columns.png',
                ),
            ),
            'default' => 'transparent',
        ),

		
	    array(
            'id' => 'menu_bg_style',
            'type' => 'background',
            'background-image' => false,
            'title' => esc_html__('Background Menu', 'chirsty'),
            'subtitle' => esc_html__('Select Background Menu style.', 'chirsty'),
            'transparent' => false,
            'preview' => false,
            'default' => array(
                'background-color' => '#ffffff')
        ),	
		

        
		array(
            'id' => 'new_class_top',
            'type' => 'switch',
            'title' => esc_html__('Class for better sub header', 'chirsty'),
            'subtitle' => esc_html__('on to have good sub header.', 'chirsty'),
            'default' => true,
        ),
		array(
            'id' => 'new_class_trip',
            'type' => 'switch',
            'title' => esc_html__('Class for better header', 'chirsty'),
            'subtitle' => esc_html__('on to have good  header.', 'chirsty'),
            'default' => true,
        ),
        
		
        
        array(
            'id' => 'a_color_header_txt',
            'type' => 'color',
            'title' => esc_html__('links color', 'chirsty'),
            'subtitle' => esc_html__('Change the top header links color.', 'chirsty'),
            'transparent' => false,
            'default' => '#222222'
        ),
        array(
            'id' => 'a_color_header_hov',
            'type' => 'color',
            'title' => esc_html__('Left links hover color', 'chirsty'),
            'subtitle' => esc_html__('Change the top header links hover color.', 'chirsty'),
            'transparent' => false,
            'default' => '#d40708'
        ),
        
        array(
            'id' => 'nav_text_section',
            'icon' => true,
            'type' => 'info',
            'style' => 'info',
            'raw' => esc_html__('Navigation Menu', 'chirsty'),
        ),
		
        array(
            'id' => 'color_nav_a',
            'type' => 'color',
            'title' => esc_html__('Link Color', 'chirsty'),
            'subtitle' => esc_html__('Specify menu link color', 'chirsty'),
            'transparent' => false,
            'default' => '#ffffff'
        ),
		
        array(
            'id' => 'color_nav_a_hov',
            'type' => 'color',
            'title' => esc_html__('Hover, active, focus', 'chirsty'),
            'subtitle' => esc_html__('Specify menu link hover color', 'chirsty'),
            'transparent' => false,
            'default' => '#ffffff'
        ),
	
        array(
            'id' => 'navbar_search',
            'type' => 'switch',
            'title' => esc_html__('Show Search in menu', 'chirsty'),
            'subtitle' => esc_html__('Click on Off to hide.', 'chirsty'),
            'default' => false,
        ),
		
    )
) );

/* Body */
Redux::setSection( $ochirsty_name,array(
    'icon' => 'el el-icon-screen',
    'title' => esc_html__('Body', 'chirsty'),
    'desc' => esc_html__('These are options to modify and style your body area', 'chirsty'),
    'fields' => array(
        array(
            'id' => 'sub_header_style_section',
            'icon' => true,
            'type' => 'info',
            'style' => 'info',
            'raw' => esc_html__('Page Title Area', 'chirsty'),
        ),
      
        array(
            'id' => 'sub_header_bg_img',
            'type' => 'media',
            'url' => true,
            'title' => esc_html__('Custom background', 'chirsty'),
            'subtitle' => esc_html__('Choose background image for page title area.', 'chirsty'),
            'default' => '',
        ),
		
        array(
            'id' => 'color_nav_ab',
            'type' => 'color',
            'title' => esc_html__('Link Color title blog', 'chirsty'),
            'subtitle' => esc_html__('Specify menu link color', 'chirsty'),
            'transparent' => false,
            'default' => '#ffffff'
        ),
		
        array(
            'id' => 'sub_header_bg_color',
            'type' => 'color',
            'title' => esc_html__('Background color', 'chirsty'),
            'subtitle' => esc_html__('If there is no Background image, specify the sub header background color', 'chirsty'),
            'transparent' => true,
            'desc' => esc_html__('The default value is transparent.', 'chirsty'),
            'default' => '#222222'
        ),
        array(
            'id' => 'color_sub_header_txt',
            'type' => 'color',
            'title' => esc_html__('Text Color', 'chirsty'),
            'subtitle' => esc_html__('Change the default text color.', 'chirsty'),
            'desc' => esc_html__('Note: this will be applied on breadcrumbs text color too.', 'chirsty'),
            'transparent' => false,
            'default' => '#d40708'
        ),


        array(
            'id' => 'body_style_section',
            'icon' => true,
            'type' => 'info',
            'style' => 'info',
            'raw' => esc_html__('Body Area', 'chirsty'),
        ),

        array(
            'id' => 'body_bg_style',
            'type' => 'background',
            'background-image' => false,
            'title' => esc_html__('Background Style', 'chirsty'),
            'subtitle' => esc_html__('Select your body background style.', 'chirsty'),
            'transparent' => false,
            'preview' => false,
            'default' => array(
                'background-color' => '#f8f8f8')
        ),
        array(
            'id' => 'color_a_text',
            'type' => 'color',
            'title' => esc_html__('a link color', 'chirsty'),
            'subtitle' => esc_html__('Color for all links', 'chirsty'),
            'transparent' => false,
            'default' => '#222222'
        ),
        array(
            'id' => 'color_a_hov',
            'type' => 'color',
            'title' => esc_html__('a link color hover', 'chirsty'),
            'subtitle' => esc_html__('Hover color for all links', 'chirsty'),
            'transparent' => false,
            'default' => '#222222'
        ),

    )
) );

/* Content */
Redux::setSection( $ochirsty_name,array(
    'icon' => 'el el-icon-blogger',
    'title' => esc_html__('Blog', 'chirsty'),
    'desc' => esc_html__('These are options to modify and style your main content area only', 'chirsty'),
    'fields' => array(
        array(
            'id' => 'post_navigation',
            'type' => 'switch',
            'title' => esc_html__('Show post navigation', 'chirsty'),
            'subtitle' => esc_html__('Check if you want to remove post navigation on single post', 'chirsty'),
            'default' => true,
        ),
        array(
            'id' => 'post_content_style_section',
            'icon' => true,
            'type' => 'info',
            'style' => 'info',
            'raw' => esc_html__('Single Post style', 'chirsty'),
        ),
		
        array(
            'id' => 'color_content_bg',
            'type' => 'color',
            'title' => esc_html__('Background color', 'chirsty'),
            'subtitle' => esc_html__('Specify content for blog post background color', 'chirsty'),
            'transparent' => false,
            'default' => '#ffffff',
        ),

        array(
            'id' => 'color_content_txt_h',
            'type' => 'color',
            'title' => esc_html__('Post title color', 'chirsty'),
            'subtitle' => esc_html__('This color will apply to post title heading, which is (H2) by default.', 'chirsty'),
            'transparent' => false,
            'default' => '#d40708'
        ),
        array(
            'id' => 'color_content_txt',
            'type' => 'color',
            'title' => esc_html__('Content text color', 'chirsty'),
            'subtitle' => esc_html__('This color will apply to text color in the content area only', 'chirsty'),
            'transparent' => false,
            'default' => '#676767'
        ),
        array(
            'id' => 'color_content_meta',
            'type' => 'color',
            'title' => esc_html__('Meta text color', 'chirsty'),
            'subtitle' => esc_html__('This color will apply to your meta data (secondary text)', 'chirsty'),
            'transparent' => false,
            'default' => '#676767'
        ),

        array(
            'id' => 'author_content_style_section',
            'icon' => true,
            'type' => 'info',
            'style' => 'info',
            'raw' => esc_html__('Author Box', 'chirsty'),
        ),
        array(
            'id' => 'blog_author_bio',
            'type' => 'switch',
            'title' => esc_html__('Enable author Bio', 'chirsty'),
            'subtitle' => esc_html__('Enable / Disable author box', 'chirsty'),
            'default' => true,
        ),
        array(
            'id' => 'author_bg_color',
            'type' => 'color',
            'title' => esc_html__('Background color', 'chirsty'),
            'subtitle' => esc_html__('Specify content area background color', 'chirsty'),
            'transparent' => false,
            'required' => array('blog_author_bio', '=', true),
            'default' => '#222222',
        ),
        array(
            'id' => 'author_txt_color',
            'type' => 'color',
            'title' => esc_html__('Content text color', 'chirsty'),
            'subtitle' => esc_html__('This color will apply to text color in the content area only', 'chirsty'),
            'transparent' => false,
            'required' => array('blog_author_bio', '=', true),
            'default' => '#ffffff'
        ),

        array(
            'id' => 'author_socials_text',
            'type' => 'text',
            'title' => esc_html__('Author Social Text', 'chirsty'),
            'subtitle' => esc_html__('Change post social text here.', 'chirsty'),
            'required' => array('author_socials', '=', true),
            'desc' => esc_html__('Leave it empty to hide it.', 'chirsty'),
            'default' => esc_html__('Follow me.', 'chirsty')
        )

    )
) );

/* Sidebar */
Redux::setSection( $ochirsty_name,array(
    'icon' => 'el el-icon-lines',
    'title' => esc_html__('Sidebar', 'chirsty'),
    'desc' => esc_html__('These are global styling settings for the sidebar area', 'chirsty'),
    'fields' => array(
        array(
            'id' => 'color_sidebar_bg',
            'type' => 'color',
            'title' => esc_html__('Background color', 'chirsty'),
            'subtitle' => esc_html__('Specify sidebar background color', 'chirsty'),
            'transparent' => false,
            'default' => '#ffffff',
        ),
        array(
            'id' => 'color_sidebar_txt_h',
            'type' => 'color',
            'title' => esc_html__('Sidebar titles color', 'chirsty'),
            'subtitle' => esc_html__('This color will apply to your sidebar titles.', 'chirsty'),
            'transparent' => false,
            'default' => '#222222'
        ),
        array(
            'id' => 'color_sidebar_txt',
            'type' => 'color',
            'title' => esc_html__('a links color', 'chirsty'),
            'subtitle' => esc_html__('This color will apply to sidebar links.', 'chirsty'),
            'transparent' => false,
            'default' => '#222222'
        ),
        array(
            'id' => 'color_sidebar_txt_hov',
            'type' => 'color',
            'title' => esc_html__('a links color hover', 'chirsty'),
            'subtitle' => esc_html__('This color will apply to sidebar links hover.', 'chirsty'),
            'transparent' => false,
            'default' => '#222222'
        ),
    )
) );

/* Footer */
Redux::setSection( $ochirsty_name,array(
    'icon' => 'el el-icon-bookmark',
    'title' => esc_html__('Footer', 'chirsty'),
    'desc' => esc_html__('Manage settings for footer area', 'chirsty'),
    'fields' => array(
   
   		array(
            'id' => 'new_class_footer',
            'type' => 'switch',
            'title' => esc_html__('Class to hide default copyright', 'chirsty'),
            'subtitle' => esc_html__('keep it as default.', 'chirsty'),
            'default' => true,
        ),
		
		array(
            'id' => 'header_socials',
            'type' => 'switch',
            'title' => esc_html__('Edit Social Icons', 'chirsty'),
            'subtitle' => esc_html__('On - to edit social icons.', 'chirsty'),
            'required' => array('hide_top_header', '=', true),
            'default' => true,
        ),
        array(
            'id' => 'facebook',
            'type' => 'text',
            'title' => esc_html__('Facebook', 'chirsty'),
            'subtitle' => esc_html__('Insert your Facebook fanpage here.', 'chirsty'),
            'desc' => "",
            'required' => array('header_socials', '=', true),
            'default' => "#"
        ),
        array(
            'id' => 'twitter',
            'type' => 'text',
            'title' => esc_html__('Twitter', 'chirsty'),
            'subtitle' => esc_html__('Insert your Twitter URL here.', 'chirsty'),
            'desc' => "",
            'required' => array('header_socials', '=', true),
            'default' => "#"
        ),
        array(
            'id' => 'dribbble',
            'type' => 'text',
            'title' => esc_html__('Dribbble', 'chirsty'),
            'subtitle' => esc_html__('Insert your Dribbble URL here.', 'chirsty'),
            'desc' => "",
            'required' => array('header_socials', '=', true),
            'default' => ""
        ),
        array(
            'id' => 'google_plus',
            'type' => 'text',
            'title' => esc_html__('Google Plus', 'chirsty'),
            'subtitle' => esc_html__('Insert your Google Plus URL here.', 'chirsty'),
            'desc' => "",
            'required' => array('header_socials', '=', true),
            'default' => ""
        ),
        array(
            'id' => 'pinterest',
            'type' => 'text',
            'title' => esc_html__('Pinterest', 'chirsty'),
            'subtitle' => esc_html__('Insert your Pinterest URL here.', 'chirsty'),
            'desc' => "",
            'required' => array('header_socials', '=', true),
            'default' => ""
        ),
        array(
            'id' => 'flickr',
            'type' => 'text',
            'title' => esc_html__('Flickr', 'chirsty'),
            'subtitle' => esc_html__('Insert your Flickr URL here.', 'chirsty'),
            'desc' => "",
            'required' => array('header_socials', '=', true),
            'default' => ""
        ),
        array(
            'id' => 'instagram',
            'type' => 'text',
            'title' => esc_html__('Instagram', 'chirsty'),
            'subtitle' => esc_html__('Insert your Instagram URL here.', 'chirsty'),
            'desc' => "",
            'required' => array('header_socials', '=', true),
            'default' => "#"
        ),
        array(
            'id' => 'vimeo',
            'type' => 'text',
            'title' => esc_html__('Vimeo', 'chirsty'),
            'subtitle' => esc_html__('Insert your Vimeo URL here.', 'chirsty'),
            'desc' => "",
            'required' => array('header_socials', '=', true),
            'default' => ""
        ),
        array(
            'id' => 'rss',
            'type' => 'text',
            'title' => esc_html__('Rss', 'chirsty'),
            'subtitle' => esc_html__('Insert your Rss URL here.', 'chirsty'),
            'desc' => "",
            'required' => array('header_socials', '=', true),
            'default' => ""
        ),
        array(
            'id' => 'linkedin',
            'type' => 'text',
            'title' => esc_html__('Linkedin', 'chirsty'),
            'subtitle' => esc_html__('Insert your Linkedin URL here.', 'chirsty'),
            'desc' => "",
            'required' => array('header_socials', '=', true),
            'default' => "#"
        ),
		
		array(
			'id'        => 'footer_copyright_text',
			'type'      => 'editor',
			'title'     => esc_html__('Footer Copyright Text', 'chirsty'),
			'subtitle'  => esc_html__('Copyright text', 'chirsty'),
			'default'   => esc_html__('2021 &copy; Prothemes. All rights reserved. ', 'chirsty'),
		),

        array(
            'id' => 'enable_footer_menu',
            'type' => 'switch',
            'title' => esc_html__('Enable Footer Menu', 'chirsty'),
            'subtitle' => esc_html__('Check if you want to show footer menu inside footer area', 'chirsty'),
            'desc' => esc_html__('Note: you need to set footer menu inside Apperance-Menu', 'chirsty'),
            'default' => false,
        ),
        
        array(
            'id' => 'footer_col',
            'type' => 'image_select',
            'compiler' => true,
            'title' => esc_html__('Footer Widget Columns', 'chirsty'),
            'subtitle' => esc_html__('Choose columns you want for your footer widgets.', 'chirsty'),
            'desc' => esc_html__('You can manage footer area content in Apperance-Widgets-Footer', 'chirsty'),
            'options' => array(
                '1' => array('alt' => '1 Column ', 'img' => CHIRSTY_IMG_URI . '/1column.png'),
                '2' => array('alt' => '2 Column ', 'img' => CHIRSTY_IMG_URI . '/2columns.png'),
                '3' => array('alt' => '3 Column ', 'img' => CHIRSTY_IMG_URI . '/3columns.png'),
                '4' => array('alt' => '4 Column ', 'img' => CHIRSTY_IMG_URI . '/4columns.png')
            ),
            'default' => '1',

        ),

		
		array(
           'id' => 'color_footer_bg',
            'type' => 'color',
            'title' => esc_html__('Background color', 'chirsty'),
            'subtitle' => esc_html__('This color will apply to footer bg.', 'chirsty'),
            'transparent' => false,
            'default' => '#222222'
        ),
		
		
        array(
            'id' => 'color_footer_txt_h',
            'type' => 'color',
            'title' => esc_html__('Footer titles color', 'chirsty'),
            'subtitle' => esc_html__('This color will apply to your footer titles.', 'chirsty'),
            'transparent' => false,
            'default' => '#f2f6fa'
        ),
        array(
            'id' => 'color_footer_txt',
            'type' => 'color',
            'title' => esc_html__('Footer Text color', 'chirsty'),
            'subtitle' => esc_html__('This color will apply to footer text.', 'chirsty'),
            'transparent' => false,
            'default' => '#ffffff'
        ),
        array(
            'id' => 'color_footer_txt_a',
            'type' => 'color',
            'title' => esc_html__('Footer a links color', 'chirsty'),
            'subtitle' => esc_html__('This color will apply to footer links.', 'chirsty'),
            'transparent' => false,
            'default' => '#f2f6fa'
        ),
        array(
            'id' => 'color_footer_txt_hov',
            'type' => 'color',
            'title' => esc_html__('Footer a links color hover', 'chirsty'),
            'subtitle' => esc_html__('This color will apply to footer links hover.', 'chirsty'),
            'transparent' => false,
            'default' => '#d40708'
        )


    )

) );

/* Typography */
Redux::setSection( $ochirsty_name,array(
    'icon' => 'el el-icon-font',
    'title' => esc_html__('Typography', 'chirsty'),
    'desc' => esc_html__('Manage fonts and typography settings', 'chirsty'),
    'fields' => array(

        array(
            'id' => 'main_font',
            'type' => 'typography',
            'title' => esc_html__('Main text font', 'chirsty'),
            'google' => true,
            'compiler' => true,
            'font-backup' => false,
            'font-size' => true,
            'color' => true,
            'subsets' => false,
            'line-height' => true,
            'text-align' => false,
            'units' => 'px',
            'subtitle' => esc_html__('Typography option with each property can be called individually.', 'chirsty'),
            'default' => array(
                'google' => true,
                'font-weight' => '400',
                'font-family' => 'Syne',
                'font-size' => '18px',
                'line-height' => '29px',
                'color' => '#666666',
            ),
            'preview' => array(
                'always_display' => true,
                'font-size' => '14px',
                'text' => esc_html__('We think that readibility is very important part of any WordPress theme. This is actually a rough example of how simple paragpraph of text will look like on your website so you have a simple preview here.', 'chirsty')
				
            )
        ),

        array(
            'id' => 'Heading_section',
            'icon' => true,
            'type' => 'info',
            'style' => 'info',
            'raw' => esc_html__('Heading Style', 'chirsty'),
        ),
        array(
            'id' => 'h1_font',
            'type' => 'typography',
            'title' => esc_html__('H1 font', 'chirsty'),
            'google' => true,
            'font-backup' => false,
            'font-size' => true,
            'color' => true,
            'line-height' => false,
            'text-align' => false,
            'subsets' => false,
            'units' => 'px',
            'subtitle' => esc_html__('Specify the H1 tag font properties.', 'chirsty'),
            'default' => array(
                'google' => true,
                'font-weight' => '400',
                'font-family' => 'Syne',
                'font-size' => '50px',
				'color' => '#222222'
            ),

            'preview' => array(
                'always_display' => true,
                'font-size' => '36px',
                'text' => esc_html__('There is no good blog without great readability', 'chirsty')
            )
        ),
        array(
            'id' => 'h2_font',
            'type' => 'typography',
            'title' => esc_html__('H2 font', 'chirsty'),
            'google' => true,
            'font-backup' => false,
            'font-size' => true,
            'color' => false,
            'line-height' => false,
            'text-align' => false,
            'subsets' => false,
            'units' => 'px',
            'subtitle' => esc_html__('Specify the H2 tag font properties.', 'chirsty'),
            'default' => array(
                'google' => true,
                'font-weight' => '400',
                'font-family' => 'Syne',
                'font-size' => '40px',
				'color' => '#222222'
            ),
            'preview' => array(
                'always_display' => true,
                'font-size' => '30px',
                'text' => esc_html__('There is no good blog without great readability', 'chirsty')
            )
        ),
        array(
            'id' => 'h3_font',
            'type' => 'typography',
            'title' => esc_html__('H3 font', 'chirsty'),
            'google' => true,
            'font-backup' => false,
            'font-size' => true,
            'color' => false,
            'line-height' => false,
            'text-align' => false,
            'subsets' => false,
            'units' => 'px',
            'subtitle' => esc_html__('Specify the H3 tag font properties.', 'chirsty'),
            'default' => array(
                'google' => true,
                'font-weight' => '400',
                'font-family' => 'Syne',
                'font-size' => '27px',
				'color' => '#222222'
            ),
            'preview' => array(
                'always_display' => true,
                'font-size' => '24px',
                'text' => esc_html__('There is no good blog without great readability', 'chirsty')
            )
        ),
        array(
            'id' => 'h4_font',
            'type' => 'typography',
            'title' => esc_html__('H4 font', 'chirsty'),
            'google' => true,
            'font-backup' => false,
            'font-size' => true,
            'color' => false,
            'line-height' => false,
            'text-align' => false,
            'subsets' => false,
            'units' => 'px',
            'subtitle' => esc_html__('Specify the H4 tag font properties.', 'chirsty'),
            'default' => array(
                'google' => true,
                'font-weight' => '400',
                'font-family' => 'Syne',
                'font-size' => '22px',
				'color' => '#222222'
            ),
            'preview' => array(
                'always_display' => true,
                'font-size' => '18px',
                'text' => esc_html__('There is no good blog without great readability', 'chirsty')
            )
        ),
        array(
            'id' => 'h5_font',
            'type' => 'typography',
            'title' => esc_html__('H5 font', 'chirsty'),
            'google' => true,
            'font-backup' => false,
            'font-size' => true,
            'color' => false,
            'line-height' => false,
            'text-align' => false,
            'subsets' => false,
            'units' => 'px',
            'subtitle' => esc_html__('Specify the H5 tag font properties.', 'chirsty'),
            'default' => array(
                'google' => true,
                'font-weight' => '400',
                'font-family' => 'Syne',
                'font-size' => '16px',
				'color' => '#222222'
            ),
            'preview' => array(
                'always_display' => true,
                'font-size' => '14px',
                'text' => esc_html__('There is no good blog without great readability', 'chirsty')
            )
        ),
        array(
            'id' => 'h6_font',
            'type' => 'typography',
            'title' => esc_html__('H6 font', 'chirsty'),
            'google' => true,
            'font-backup' => false,
            'font-size' => true,
            'color' => false,
            'line-height' => false,
            'text-align' => false,
            'subsets' => false,
            'units' => 'px',
            'subtitle' => esc_html__('Specify the H6 tag font properties.', 'chirsty'),
            'default' => array(
                'google' => true,
                'font-weight' => '400',
                'font-family' => 'Syne',
                'font-size' => '17px',
				'color' => '#222222'
            ),
            'preview' => array(
                'always_display' => true,
                'font-size' => '12px',
                'text' => esc_html__('There is no good blog without great readability', 'chirsty')
            )
        ),
        array(
            'id' => 'nav_font',
            'type' => 'typography',
            'title' => esc_html__('Navigation font', 'chirsty'),
            'google' => true,
            'compiler' => true,
            'font-backup' => false,
            'font-size' => true,
			'font-weight' => true,
            'color' => false,
            'line-height' => false,
            'text-align' => false,
            'subsets' => false,
            'units' => 'px',
            'subtitle' => esc_html__('Typography option with each property can be called individually.', 'chirsty'),
            'default' => array(
                'google' => true,
                'font-weight' => '500',
                'font-family' => 'Syne',
                'font-size' => '16px',
				'color' => '#ffffff'
            ),
            'preview' => array(
                'always_display' => true,
                'font-size' => '14px',
                'text' => esc_html__('Home &nbsp;&nbsp;About &nbsp;&nbsp;Blog &nbsp;&nbsp;Contact', 'chirsty')
            )
        ),
    )
) );
