<?php

/**
 * Chirsty - setup
 * @package Chirsty
 * @since Chirsty 1.0
 */

define('CHIRSTY_THEME_OPTIONS', 'chirsty_settings');
define('CHIRSTY_THEME_DIR', get_template_directory());
define('CHIRSTY_THEME_URI', get_template_directory_uri());
define('CHIRSTY_JS_URI',  CHIRSTY_THEME_URI . '/includes/js');
define('CHIRSTY_CSS_URI', CHIRSTY_THEME_URI . '/includes/css');
define('CHIRSTY_IMG_DIR', CHIRSTY_THEME_DIR . '/images');
define('CHIRSTY_IMG_URI', CHIRSTY_THEME_URI . '/images');

if ( ! isset( $content_width )) {
  $content_width = 669; 
}

// WooCommerce
function chirsty_add_woocommerce_support() {
    add_theme_support( 'woocommerce' );
}
add_action( 'after_setup_theme', 'chirsty_add_woocommerce_support' );


//Add a pingback url auto-discovery header for single posts, pages, or attachments.

function chirsty_pingback_header() {
  if ( is_singular() && pings_open() ) {
    printf( '<link rel="pingback" href="%s">' . "\n", esc_url( get_bloginfo( 'pingback_url' ) ) );
  }
}
add_action( 'wp_head', 'chirsty_pingback_header' );


//WooCommerce custom
add_filter( 'woocommerce_show_page_title', '__return_false' );

function chirsty_woocommerce_setup() {
	add_theme_support( 'woocommerce' );
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
}
add_action( 'after_setup_theme', 'chirsty_woocommerce_setup' );


add_filter('loop_shop_columns', 'loop_columns');
if (!function_exists('loop_columns')) {
	function loop_columns() {
		return 3; // 3 products per row
	}
}
function woo_related_products_limit() {
  global $product;
	
	$args['posts_per_page'] = 6;
	return $args;
}
add_filter( 'woocommerce_output_related_products_args', 'chirsty_related_products_args' );
  function chirsty_related_products_args( $args ) {
	$args['posts_per_page'] = 3; // 4 related products
	$args['columns'] = 3; // arranged in 2 columns
	return $args;
}

// Get Google Fonts URL

if ( !function_exists('chirsty_fonts') ):
function chirsty_fonts() {
	wp_enqueue_style( 'chirsty-google-fonts', chirsty_google_fonts_url(), array(), null );
}
add_action( 'wp_enqueue_scripts', 'chirsty_fonts' );
endif;

function chirsty_google_fonts_url() {
	$fonts_url = '';
	$robotoslab = _x( 'on', 'roboto slab font: on or off', 'chirsty' );
	$syne = _x( 'on', 'syne font: on or off', 'chirsty' );
	
	if ('off' !== $syne) {
		$font_families = array();
		
		if ( 'off' !== $robotoslab ) {
			$font_families[] = 'Roboto+Slab:300,400,500,600,700,800';
		}
		
		if ( 'off' !== $syne ) {
			$font_families[] = 'Syne:400,500,600,700,800';
		}

		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( 'latin,latin-ext' ),
		);
		
		$fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css2' );
	}
	
	return esc_url_raw( $fonts_url );
}

//end font

function chirsty_add_editor_styles() {
    add_editor_style( 'editor-style.css' );
}
add_action( 'admin_init', 'chirsty_add_editor_styles' );

/**
    Theme setup
**/

if ( !function_exists( 'chirsty_setup' ) ) {

  function chirsty_setup() {
    add_theme_support( 'automatic-feed-links');
    add_theme_support( 'title-tag' );
    add_theme_support( 'post-thumbnails');
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'align-wide' );
	add_theme_support( 'editor-styles' );
	
    load_theme_textdomain( 'chirsty', CHIRSTY_THEME_DIR . '/languages' );

    // Register Menus
    register_nav_menus(
      array(
        'primary'     => esc_html__( 'Primary', 'chirsty' ),
        'mobilem'	  => esc_html__( 'Mobile Menu', 'chirsty' ),
		'footer-menu' => esc_html__( 'Footer Menu', 'chirsty' )
        ) 
      );

    // allows users to set a custom background.
    add_theme_support( 'custom-background', apply_filters( 'chirsty_custom_background_args', array(
      'default-color' => 'f5f5f5',
      )));

    //add image sizes
    add_image_size('chirsty-featured_image', 669, 272, true);
    add_image_size('chirsty-small-thumb',  50, 50, true);
    add_image_size('chirsty-full-size', 9999, 9999, false);
	add_image_size('chirsty_portfolio01_390x275', 390, 275, true);
  }
}

add_action( 'after_setup_theme', 'chirsty_setup' );

/**
    Getting post thumbnail url
 */
function chirsty_get_thumb_url($pots_ID){
  return wp_get_attachment_url( get_post_thumbnail_id( $pots_ID ) );
}

/*remove redux demo*/
/** remove redux menu under the tools **/
add_action( 'admin_menu', 'remove_redux_menu',12 );
function remove_redux_menu() {
    remove_submenu_page('tools.php','redux-about');
}

/**
    Load Required Files
**/
// Load Redux framework admin panel

if ( ! function_exists( 'redux_disable_dev_mode_plugin' ) ) {
        function redux_disable_dev_mode_plugin( $redux ) {
            if ( $redux->args['ochirsty_name'] != 'redux_demo' ) {
                $redux->args['dev_mode'] = false;
            }
        }

        add_action( 'redux/construct', 'redux_disable_dev_mode_plugin' );
    }

if (!isset($redux_demo)){
	include_once get_template_directory() . '/admin/custom/redux-config.php';
}
//

// Clean style
function chirsty_support() {
    add_theme_support(
        'html5',
        array(
            'script', 
            'style',
        )
    );
}
add_action( 'after_setup_theme', 'chirsty_support' );


include_once get_template_directory() . '/admin/custom/redux-config.php';


// Required Redux framework functions
include_once get_template_directory() . '/admin/custom/theme-options.php';


// Chirsty Styles and Scripts 
include_once get_template_directory() . '/admin/custom/core/scripts.php';

// Chirsty Sidebars, widgets and menus
include_once get_template_directory() . '/admin/custom/core/register.php';

// Custom functions & snippets
include_once get_template_directory() . '/admin/custom/core/clean.php';
include_once get_template_directory() . '/admin/custom/core/snippets.php';
include_once get_template_directory() . '/admin/custom/core/jetpack.php';

// Bootstrap Style Breadcrumbs
include_once get_template_directory() . '/includes/breadcrumbs.php';

// Bootstrap nav walker
include_once get_template_directory() . '/includes/bootstrap-walker.php';

// Bootstrap nav walker for footer
include_once get_template_directory() . '/includes/bootstrap-walker-footer.php';

// Custom template tags
include_once get_template_directory() . '/includes/template-tags.php';

//include tgma
require_once get_template_directory() . '/includes/class-tgm-plugin-activation.php';
add_action( 'chirsty_register', 'chirsty_register_required_plugins' );

function chirsty_register_required_plugins() {
    $plugins = array(
      
		array(
			'name'      => esc_html__('Redux framework','chirsty'),
			'slug'      => 'redux-framework',
			'required'  => false,
),
		array(
			'name'      => esc_html__('Elementor Page Builder','chirsty'),
			'slug'      => 'elementor',
			'required'  => false,
),		
		array(
			'name'      => esc_html__('Unlimited Elements for Elementor','chirsty'),
			'slug'      => 'unlimited-elements-for-elementor',
			'required'  => false,
),	
		array(
			'name'      => esc_html__('Header Footer Elementor','chirsty'),
			'slug'      => 'header-footer-elementor',
			'required'  => false,
),				
	
		array(
			'name'      => esc_html__('Contact Form 7','chirsty'),
			'slug'      => 'contact-form-7',
			'required'  => false,
),	
		array(
			'name'      => esc_html__('GiveWP – Donation Plugin and Fundraising Platform','chirsty'),
			'slug'      => 'give',
			'required'  => false,
),		
		array(
			'name'      => esc_html__('Charity Addon for Elementor','chirsty'),
			'slug'      => 'charity-addon-for-elementor',
			'required'  => false,
),						
			
		array(
			'name'      => esc_html__('Ajax Search Popup','chirsty'),
			'slug'      => 'ajax-search-popup',
			'required'  => false,
),							
			
		array(
			'name'      => esc_html__('All-in-One WP Migration'),
			'slug'      => 'all-in-one-wp-migration',
			'required'  => false,
),	
	
        
    );  

$config = array(
		'id'           => 'chirsty', 
		'default_path' => '', 
		'menu'         => 'chirsty-install-plugins',
		'parent_slug'  => 'themes.php',	
		'capability'   => 'edit_theme_options',
		'has_notices'  => true,    
		'dismissable'  => true,   
		'dismiss_msg'  => '',   
		'is_automatic' => false, 
		'message'      => '', 
	
	);
    chirsty( $plugins, $config );
}

 
?>